# GuteCompiler
## Overview
This is a compiler built from scratch using Python3.
The language used is follows[this grammar specification](./grammar.pdf).


## Requirements
- Python3.7

## Running the Compiler
In a terminal or command line, navigate to the directory of the project

Give executable permissions to the setup.sh file with `chmod +x setup.sh` to make life easy for you

Run the command `. ./setup.sh` for a quick Python3.7 version check, and installation

After all that magic, you're ready to use my compiler

Type `gutec path_to_a_file` to compile a file

To exit the virtual environment, type `deactivate`

As of now, the compiler can only perform lexical analysis but more will come...
